@@ -15,16 +15,15 @@ class SnakeSkin(BasicNamespace):
     egg_plugins = ["teamrubber.snakeskin", ]
 
     vars = copy.deepcopy(BasicNamespace.vars)
-    get_var(vars, 'namespace_package').default = 'plonetheme'
-    get_var(vars, 'namespace_package').description = 'Namespace package (like plonetheme)'
+    get_var(vars, 'namespace_package').default = 'clienttheme'
+    get_var(vars, 'namespace_package').description = 'Namespace package (like clienttheme)'
     get_var(vars, 'description').default = 'A theme based on an existing arbitrary plone 3 theme.'
     get_var(vars, 'zip_safe').default = False
     
     vars = vars[:3] + [
-        var("theme_name", "The name of this theme"),
-        var("base_theme", "The package containing the theme to base on"),
-        var("base_spec", "The same as above with an optional version specification"),
-        var("basename", "The name of the Zope skin layer the above theme provides", default="Plone Default"),
+        var("theme_name", "The name of this theme", default="Client Skin"),
+        var("base_theme", "The package containing the theme to base on (the name of the egg)", default="plonetheme.example"),
+        var("basename", "The name of the Zope skin layer the above theme provides", default="My Theme"),
     ] + vars[3:]
 
     def pre(self, command, output_dir, vars):
